@@ -5,7 +5,7 @@
  * Massachusetts.
  *
  * Enhancements Copyright 1992-2001, 2002, 2003, 2004, 2005, 2006,
- * 2007, 2008, 2009, 2010, 2011, 2012 Free Software Foundation, Inc.
+ * 2007, 2008, 2009, 2010, 2011, 2012, 2013 Free Software Foundation, Inc.
  *
  * Enhancements Copyright 2005 Alessandro Scotti
  *
@@ -51,8 +51,8 @@
  *------------------------------------------------------------------------
  ** See the file ChangeLog for a revision history.  */
 
-#ifndef _BACKEND
-#define _BACKEND
+#ifndef XB_BACKEND
+#define XB_BACKEND
 
 /* unsigned int 64 for engine nodes work and display */
 #ifdef WIN32
@@ -95,8 +95,10 @@
 #endif
 
 #include "lists.h"
-#include "frontend.h"
 
+typedef int (*FileProc) P((FILE *f, int n, char *title));
+
+extern char *wbOptions;
 extern int gotPremove;
 extern GameMode gameMode;
 extern int matchMode;
@@ -107,12 +109,14 @@ extern int currentMove, backwardMostMove, forwardMostMove;
 extern int blackPlaysFirst;
 extern FILE *debugFP;
 extern char* programVersion;
-extern ProcRef firstProgramPR, secondProgramPR;
 extern Board boards[];
 extern char marker[BOARD_RANKS][BOARD_FILES];
 extern char lastMsg[MSG_SIZ];
 extern Boolean bookUp;
+extern int tinyLayout, smallLayout;
+extern Boolean mcMode;
 
+void MarkMenuItem P((char *menuRef, int state));
 char *CmailMsg P((void));
 /* Tord: Added the useFEN960 parameter in PositionToFEN() below */
 char *PositionToFEN P((int move, char* useFEN960));
@@ -205,7 +209,7 @@ void MailMoveEvent P((void));
 void EditTagsEvent P((void));
 void GetMoveListEvent P((void));
 void ExitAnalyzeMode P((void));
-void AnalyzeModeEvent P((void));
+int  AnalyzeModeEvent P((void));
 void AnalyzeFileEvent P((void));
 void MatchEvent P((int mode));
 void RecentEngineEvent P((int nr));
@@ -230,7 +234,7 @@ void OutputChatMessage P((int partner, char *mess));
 void EditPositionDone P((Boolean fakeRights));
 Boolean GetArgValue P((char *name));
 Boolean LoadPV P((int x, int y));
-Boolean LoadMultiPV P((int x, int y, char *buf, int index, int *start, int *end));
+Boolean LoadMultiPV P((int x, int y, char *buf, int index, int *start, int *end, int pane));
 void UnLoadPV P(());
 void MovePV P((int x, int y, int h));
 int PromoScroll P((int x, int y));
@@ -241,6 +245,10 @@ int PackGame P((Board board));
 Boolean ParseFEN P((Board board, int *blackPlaysFirst, char *fen));
 void ApplyMove P((int fromX, int fromY, int toX, int toY, int promoChar, Board board));
 void PackMove P((int fromX, int fromY, int toX, int toY, ChessSquare promoPiece));
+void ics_printf P((char *format, ...));
+int GetEngineLine P((char *nick, int engine));
+void AddGameToBook P((int always));
+void FlushBook P((void));
 
 char *StrStr P((char *string, char *match));
 char *StrCaseStr P((char *string, char *match));
@@ -261,13 +269,8 @@ int ToUpper P((int c));
 extern GameInfo gameInfo;
 
 /* ICS vars used with backend.c and zippy.c */
-#define ICS_GENERIC 0
-#define ICS_ICC 1
-#define ICS_FICS 2
-#define ICS_CHESSNET 3 /* not really supported */
-int ics_type;
-
- 
+enum ICS_TYPE { ICS_GENERIC, ICS_ICC, ICS_FICS, ICS_CHESSNET /* not really supported */ };
+enum ICS_TYPE ics_type;
 
 /* pgntags.c prototypes
  */
@@ -281,7 +284,7 @@ char *PGNResult P((ChessMove result));
  */
 /* A game node in the double linked list of games.
  */
-typedef struct _ListGame {
+typedef struct XB_ListGame {
     ListNode node;
     int number;
     int position;
@@ -289,7 +292,8 @@ typedef struct _ListGame {
     unsigned long offset;   /*  Byte offset of game within file.     */
     GameInfo gameInfo;      /*  Note that some entries may be NULL. */
 } ListGame;
- 
+
+extern int doubleClick;
 extern int storedGames;
 extern int opponentKibitzes;
 extern ChessSquare gatingPiece;
@@ -317,18 +321,11 @@ extern Boolean set_cont_sequence P((char *new_seq));
 extern int wrap P((char *dest, char *src, int count, int width, int *lp));
 int Explode P((Board board, int fromX, int fromY, int toX, int toY));
 
-typedef enum { CheckBox, ComboBox, TextBox, Button, Spin, ResetButton, SaveButton,
-		 FileName, PathName, Slider, Message, Fractional, Label, Break, EndMark } Control;
+typedef enum { CheckBox, ComboBox, TextBox, Button, Spin, ResetButton, SaveButton, ListBox, Graph, PopUp,
+		 FileName, PathName, Slider, Message, Fractional, Label, Icon,
+		 BoxBegin, BoxEnd, BarBegin, BarEnd, DropDown, Break, EndMark } Control;
 
-/* Flags Option.min used for ComboBox: */
-#define COMBO_CALLBACK	(1 << 0)
-#define NO_GETTEXT	(1 << 1)
-
-/* Flags for Option.min used for Button, SaveButton, EndMark: */
-#define SAME_ROW	(1 << 0)
-#define NO_OK		(1 << 1)
-
-typedef struct _OPT {   // [HGM] options: descriptor of UCI-style option
+typedef struct XB_OPT {   // [HGM] options: descriptor of UCI-style option
     int value;          // current setting, starts as default
     int min;		// Also used for flags
     int max;
@@ -337,10 +334,10 @@ typedef struct _OPT {   // [HGM] options: descriptor of UCI-style option
     char *textValue;    // points to beginning of text value in name field
     char **choice;      // points to array of combo choices in cps->combo
     Control type;
-    char name[MSG_SIZ]; // holds both option name and text value
+    char *name;         // holds both option name and text value (in allocated memory)
 } Option;
 
-typedef struct _CPS {
+typedef struct XB_CPS {
     char *which;
     int maybeThinking;
     ProcRef pr;
@@ -349,7 +346,7 @@ typedef struct _CPS {
     char *program;
     char *host;
     char *dir;
-    struct _CPS *other;
+    struct XB_CPS *other;
     char *initString;
     char *computerString;
     int sendTime; /* 0=don't, 1=do, 2=test */
@@ -371,6 +368,7 @@ typedef struct _CPS {
     int sendName;    /* 0=don't use "name" command; 1=do */
     int sdKludge;    /* 0=use "sd DEPTH" command; 1=use "depth\nDEPTH" */
     int stKludge;    /* 0=use "st TIME" command; 1=use "level 1 TIME" */
+    int excludeMoves;/* 0=don't use "exclude" command; 1=do */
     char tidy[MSG_SIZ];
     int matchWins;
     char variants[MSG_SIZ];
@@ -400,6 +398,7 @@ typedef struct _CPS {
     int memSize;      /* [HGM] memsize: engine understands memory command   */
     char egtFormats[MSG_SIZ];     /* [HGM] EGT: supported tablebase formats */
     int bookSuspend;  /* [HGM] book: go was deferred because of book hit    */
+    int pause;        /* [HGM] pause: 1=supports it, 2=actually paused      */
     int nrOptions;    /* [HGM] options: remembered option="..." features    */
 #define MAX_OPTIONS 200
     Option option[MAX_OPTIONS];
@@ -409,6 +408,7 @@ typedef struct _CPS {
     void *programLogo; /* [HGM] logo: bitmap of the logo                    */
     char *fenOverride; /* [HGM} FRC: force FEN casling & ep fields by hand  */
     char userError;    /* [HGM] crash: flag to suppress fatal-error messages*/
+    char reload;       /* [HGM] options: flag to resend options with xreuse */
 } ChessProgramState;
 
 extern ChessProgramState first, second;
@@ -436,13 +436,16 @@ extern ChessProgramStats programStats;
 extern int opponentKibitzes; // used by wengineo.c
 extern int errorExitStatus;
 extern char *recentEngines;
+extern char *comboLine;
+extern Boolean partnerUp, twoBoards;
 void SettingsPopUp P((ChessProgramState *cps)); // [HGM] really in front-end, but CPS not known in frontend.h
 int WaitForEngine P((ChessProgramState *cps, DelayedEventCallback x));
 void Load P((ChessProgramState *cps, int n));
 int MultiPV P((ChessProgramState *cps));
 void MoveHistorySet P(( char movelist[][2*MOVE_LEN], int first, int last, int current, ChessProgramStats_Move * pvInfo ));
-void EvalGraphSet P(( int first, int last, int current, ChessProgramStats_Move * pvInfo ));
 void MakeEngineOutputTitle P((void));
+void LoadTheme P((void));
+void CreateBookEvent P((void));
 
 /* A point in time */
 typedef struct {
@@ -453,4 +456,4 @@ typedef struct {
 void GetTimeMark P((TimeMark *));
 long SubtractTimeMarks P((TimeMark *, TimeMark *));
 
-#endif /* _BACKEND */
+#endif /* XB_BACKEND */
