@@ -58,7 +58,7 @@
 #define IDM_Comment                     173
 #define IDM_Debug                       174
 #define IDM_EditProgs1                  175
-#define IDM_EditProgs2                  176
+#define IDM_LoadProg1                   176
 #define IDM_AnalysisMode                177
 #define IDM_AnalyzeFile                 178
 #define IDM_Annotate                    179
@@ -71,6 +71,7 @@
 #define IDM_MachineBoth                 186  
 #define IDM_MuteSounds                  187
 #define IDM_Match                       188
+#define IDM_CreateBook                  189
 #define OPT_TCtext1                     202
 #define OPT_TCTime                      203
 #define OPT_TCtext2                     204
@@ -110,6 +111,7 @@
 #define DLG_NewGameFRC                  457
 #define DLG_GameListOptions             458
 #define DLG_MoveHistory                 459
+#define IDM_ThemeOptions                460
 #define DLG_EvalGraph                   461
 #define DLG_EngineOutput                463
 #define DLG_EnginePlayOptions           464
@@ -197,6 +199,7 @@
 #define OPT_GameListPrev                1010
 #define OPT_GameListText                1011
 #define OPT_GameListLoad                1012
+#define OPT_GameListNarrow              1010
 #define OPT_GameListNext                1013
 #define OPT_GameListClose               1014
 #define DLG_EditTags                    1015
@@ -336,6 +339,7 @@
 #define CBO_Sounds                      1350
 #define OPT_DefaultSounds               1351
 #define OPT_AlwaysOnTop                 1352
+#define OPT_AutoCreate                  1352
 #define OPT_AutoFlag                    1353
 #define OPT_AlwaysQueen                 1354
 #define OPT_AutoComment                 1354
@@ -626,6 +630,7 @@
 #define OPT_ChoosePieceFont             1980
 #define OPT_GameListFind                1981
 #define OPT_Grid                        1983
+#define IDM_LoadProg2                   1984
 
 
 // Next default values for new objects
